@@ -42,7 +42,10 @@ class Display:
         if mode == "work":
             self.print_header_small()
             print(
-                self.col(f"Tasks for {calendar.day_name[get_weekday()]} {get_today()}", "lblue")
+                self.col(
+                    f"Tasks for {calendar.day_name[get_weekday()]} {get_today()}",
+                    "lblue",
+                )
             )
             print(self.col("-----------------------------------------", "lblue"))
             self.print_tasks(tasks)
@@ -55,7 +58,9 @@ class Display:
             )
         else:
             self.print_header_small()
-            print(self.col(f"{calendar.day_name[get_weekday()]} {get_today()}", 'lblue'))
+            print(
+                self.col(f"{calendar.day_name[get_weekday()]} {get_today()}", "lblue")
+            )
             print(self.col("-----------------------------------------", "lblue"))
             print(
                 f"\n{self.col('Press')} {self.col('Ctrl-C', 'yellow')} "
@@ -87,12 +92,30 @@ class Display:
         )
 
     def print_bar_header(self):
-        print(
-            f"{self.col('Daily work/rest minutes, for the past fortnight', 'yellow')}"
-        )
+        print(f"{self.col('Daily work/rest minutes, for the past fortnight', 'lblue')}")
+
+    def print_busy_days_header(self):
+        print("\n")
+        print(f"{self.col('Ways of working', 'lblue')}")
 
     def print_heat_header(self):
-        print(f"{self.col(f'{self.add_plurality(self.pom_name)} heatmap', 'yellow')}")
+        print(f"{self.col(f'{self.add_plurality(self.pom_name)} heatmap', 'lblue')}")
+
+    def print_today_totals_header(self):
+        print("\n")
+        print(f"{self.col(f'Totals for today', 'lblue')}")
+
+    def print_busy_days(self, created_at_day: str, completed_at_day: str):
+        print(
+            "\n"
+            + tr.fill(
+                f"Your favourite day for opening new tasks is "
+                f"{self.col(created_at_day, 'lred')},"
+                f" while {self.col(self.add_plurality(completed_at_day),'lgreen')} "
+                f"are your busiest days for closing them.\n",
+                75,
+            )
+        )
 
     def cursor(self):
         return self.col(">> ", "yellow")
@@ -108,7 +131,9 @@ class Display:
         )
 
     def print_offer_options(self):
-        print(f"\n{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}")
+        print(
+            f"\n{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}"
+        )
 
     def print_add_task_or_quit(self):
         print("\n")
@@ -147,10 +172,12 @@ class Display:
     def print_splash(self, mode: str, tasks: List):
         print(
             self.col(
-                f"Tasks for today, {calendar.day_name[get_weekday()]} {get_today()}", "lblue"
+                f"TODAY: {calendar.day_name[get_weekday()].upper()} {get_today()} "
+                f"------------------",
+                "lblue",
             )
         )
-        print(self.col("-----------------------------------------", "lblue"))
+        print("\n")
         self.print_tasks(tasks)
 
     def print_splash_prompt(self, mode: str):
@@ -275,7 +302,15 @@ class Display:
             if int(self.simple_colors) == 1:
                 colors = ["lred", "yellow", "lgreen", "lblue", "lmagenta"]
             else:
-                colors = ["lred", "lyellow", "yellow", "lgreen", "lblue", "lmagenta", "magenta"]
+                colors = [
+                    "lred",
+                    "lyellow",
+                    "yellow",
+                    "lgreen",
+                    "lblue",
+                    "lmagenta",
+                    "magenta",
+                ]
             shuffle(colors)
 
             # This nasty work-around is because using ascii_header prints each letter to a new row.
