@@ -201,9 +201,11 @@ def bootstrap():
 
     CREATE TABLE IF NOT EXISTS tasks (
         id INTEGER PRIMARY KEY,
-        task_date date,
+        created_at date,
+        completed_at date,
         description text,
         effort int,
-        complete bool
+        complete bool,
+        number_of_times_moved int
     );
     """
