@@ -65,11 +65,11 @@ class Timer:
         self.tasks = database.select(
             f"SELECT"
             f'"id",'
-            f'"task_date",'
+            f'"created_at",'
             f'"description",'
             f'"effort",'
             f'"complete"'
-            f"FROM tasks WHERE \"task_date\" = '{get_today()}' "
+            f"FROM tasks WHERE \"created_at\" = '{get_today()}' "
             f";"
         )
         self.display = display
@@ -188,7 +188,6 @@ class Insights:
 
     def print_bar(self):
         global initial_boot_flag
-        self.display.print_header_small()
         self.display.print_bar_header()
         if initial_boot_flag is False:
             logger.info(f"Running ${self._bar_chart()}")
@@ -207,6 +206,31 @@ class Insights:
     def _heat_map(self):
         return METRICS_HEAT % (self.heatmap_start_date, self.poms_file)
 
+    def print_busy_days(self):
+        query = (
+            ""
+            "SELECT "
+            "case cast (strftime('%w', {}) as integer)"
+            "when 0 then 'Sunday'"
+            "when 1 then 'Monday'"
+            "when 2 then 'Tuesday'"
+            "when 3 then 'Wednesday'"
+            "when 4 then 'Thursday'"
+            "when 5 then 'Friday'"
+            "else 'Saturday' end as dayofweek,"
+            "count(*) "
+            "FROM tasks "
+            "GROUP BY 1 "
+            "ORDER BY 2 desc "
+            "LIMIT 1"
+        )
+        busiest_day_created = database.select(query.format("created_at"))
+        businest_day_completed = database.select(query.format("completed_at"))
+        self.display.print_busy_days_header()
+        self.display.print_busy_days(
+            busiest_day_created[0][0], businest_day_completed[0][0]
+        )
+
 
 class Task:
     def __init__(self):
@@ -218,15 +242,17 @@ class Task:
     def write_task_to_db(self):
         database.execute(
             f"INSERT INTO tasks ("
-            f'"task_date", '
+            f'"created_at", '
             f'"description", '
             f'"effort", '
-            f'"complete"'
+            f'"complete", '
+            f'"number_of_times_moved"'
             f") VALUES("
             f'"{self.date}",'
             f'"{self.description}",'
             f'"{self.effort}",'
-            f'"{self.complete}");'
+            f'"{self.complete}",'
+            f"0);"
         )
 
 
@@ -274,15 +300,17 @@ class Sylo:
 
     def show_task(self, dates, with_id: bool = False):
         for date in dates:
-            print(self.display.col(f"--------------------------------- {date}", "lblue"))
+            print(
+                self.display.col(f"--------------------------------- {date}", "lblue")
+            )
             self.tasks = database.select(
                 f"SELECT"
                 f'"id",'
-                f'"task_date",'
+                f'"created_at",'
                 f'"description",'
                 f'"effort",'
                 f'"complete"'
-                f"FROM tasks WHERE \"task_date\" = '{date}'"
+                f"FROM tasks WHERE \"created_at\" = '{date}'"
                 f";"
             )
             if with_id is False:
@@ -320,8 +348,10 @@ class Sylo:
             sleep(1)
             self.task_menu(dates)
         database.execute(
-            f'UPDATE tasks SET "complete" = '
-            f'CASE WHEN "complete" = False THEN True ELSE False END'
+            f"UPDATE tasks SET "
+            f'"complete" = '
+            f'CASE WHEN "complete" = False THEN True ELSE False END, '
+            f'"completed_at" = "{get_today()}"'
             f' WHERE "id" = {comp_input};'
         )
         self.task_menu(dates)
@@ -337,7 +367,9 @@ class Sylo:
             sleep(1)
             self.task_menu(dates)
         database.execute(
-            f"UPDATE tasks SET \"task_date\" = '{get_today()}'"
+            f"UPDATE tasks SET "
+            f"\"created_at\" = '{get_today()}',"
+            f'"number_of_times_moved" = "number_of_times_moved" + 1'
             f' WHERE "id" = {comp_input};'
         )
         self.task_menu(dates)
@@ -360,16 +392,18 @@ class Sylo:
         all_tasks = self.tasks = database.select(
             f"SELECT"
             f'"id",'
-            f'"task_date",'
+            f'"created_at",'
             f'"description",'
             f'"effort",'
             f'"complete"'
-            f'FROM tasks WHERE "task_date" '
+            f'FROM tasks WHERE "created_at" '
             f">= (SELECT DATETIME({(get_today())}, '-7 day'))"
             f";"
         )
         all_task_ids = [i[0] for i in all_tasks]
         self.display.print_header_small()
+        print(self.display.col("ADD/REMOVE/MOVE TASKS ----------------------", "lblue"))
+        print("\n")
         self.show_task(dates)
         self.display.print_add_task_or_quit()
         usr_input = input(self.display.cursor())
@@ -400,8 +434,14 @@ class Sylo:
         clear_screen()
         metrics = Insights(self.display)
         metrics.save_files()
+        self.display.print_header_small()
+        print(self.display.col("INSIGHTS -----------------------------------", "lblue"))
+
+        print("\n")
         metrics.print_bar()
         metrics.print_heat()
+        metrics.print_busy_days()
+        self.display.print_today_totals_header()
         self.display.print_insights()
         input(self.display.cursor())
         self.home_loop()
@@ -557,12 +597,12 @@ def run(args, config):
         tasks=database.select(
             f"SELECT"
             f'"id",'
-            f'"task_date",'
+            f'"created_at",'
             f'"description",'
             f'"effort",'
             f'"complete"'
             f"FROM tasks "
-            f"WHERE \"task_date\" = '{get_today()}'"
+            f"WHERE \"created_at\" = '{get_today()}'"
             f";"
         ),
         config=config,
